.. _spkg_sagemath_kenzo:

=========================================================================================
sagemath_kenzo: Topological spaces and homology groups with kenzo
=========================================================================================

About SageMath
--------------

   "Creating a Viable Open Source Alternative to
    Magma, Maple, Mathematica, and MATLAB"

   Copyright (C) 2005-2024 The Sage Development Team

   https://www.sagemath.org

SageMath fully supports all major Linux distributions, recent versions of
macOS, and Windows (Windows Subsystem for Linux).

See https://doc.sagemath.org/html/en/installation/index.html
for general installation instructions.


About this pip-installable distribution package
-----------------------------------------------

This pip-installable distribution ``passagemath-kenzo`` provides an interface
to the package `Kenzo <https://github.com/miguelmarco/kenzo/>`_.


What is included
----------------

* Binary wheels on PyPI contain prebuilt copies of the kenzo FASL.

Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cython`
- :ref:`spkg_kenzo`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_ecl`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_sagemath_graphs`
- :ref:`spkg_sagemath_modules`

Version Information
-------------------

package-version.txt::

    10.5.27

version_requirements.txt::

    passagemath-kenzo ~= 10.5.27.0


Equivalent System Packages
--------------------------

(none known)

